@@ -1,4 +1,8 @@
 import json
+import os
+
+if "PORT" in os.environ:
+    print(os.environ["PORT"])
 
 try:
     with open("config.json") as file:
